==> aria2_0.12.1.orig.tar.gz: aria2-0.12.1/src/StreamFileAllocationEntry.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "StreamFileAllocationEntry.h"
#include "CUIDCounter.h"
#include "Command.h"
#include "DownloadEngine.h"
#include "Option.h"
#include "Request.h"
#include "prefs.h"
#include "RequestGroup.h"
#include "InitiateConnectionCommandFactory.h"

StreamFileAllocationEntry::StreamFileAllocationEntry(const RequestHandle& currentRequest,
						     RequestGroup* requestGroup,
						     Command* nextCommand):
  FileAllocationEntry(requestGroup, nextCommand),
  _currentRequest(currentRequest)
{}

StreamFileAllocationEntry::~StreamFileAllocationEntry() {}

Commands StreamFileAllocationEntry::prepareForNextAction(DownloadEngine* e)
{
  Commands commands;
  if(_nextCommand) {
    commands.push_back(popNextCommand());
    // try remaining uris
    Commands streamCommands = _requestGroup->createNextCommandWithAdj(e, -1);
    copy(streamCommands.begin(), streamCommands.end(), back_inserter(commands));
  } else {
    if(_currentRequest.isNull()) {
      commands = _requestGroup->createNextCommandWithAdj(e, 0);
    } else {
      Commands streamCommands = _requestGroup->createNextCommandWithAdj(e, -1);
      Command* command = InitiateConnectionCommandFactory::createInitiateConnectionCommand(CUIDCounterSingletonHolder::instance()->newID(),
											   _currentRequest, _requestGroup, e);
      
      commands.push_back(command);
      copy(streamCommands.begin(), streamCommands.end(), back_inserter(commands));
    }
  }
  return commands;
}

==> aria2_1.1.2.orig.tar.gz: aria2-1.1.2/src/StreamFileAllocationEntry.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "StreamFileAllocationEntry.h"

#include <algorithm>

#include "DownloadEngine.h"
#include "Option.h"
#include "Request.h"
#include "prefs.h"
#include "RequestGroup.h"
#include "InitiateConnectionCommandFactory.h"
#include "DownloadContext.h"

namespace aria2 {

StreamFileAllocationEntry::StreamFileAllocationEntry(const RequestHandle& currentRequest,
						     RequestGroup* requestGroup,
						     Command* nextCommand):
  FileAllocationEntry(requestGroup, nextCommand),
  _currentRequest(currentRequest)
{}

StreamFileAllocationEntry::~StreamFileAllocationEntry() {}

void StreamFileAllocationEntry::prepareForNextAction(std::deque<Command*>& commands,
						     DownloadEngine* e)
{
  _requestGroup->getDownloadContext()->resetDownloadStartTime();
  if(_nextCommand) {
    // give _nextCommand a chance to execute in the next execution loop.
    _nextCommand->setStatus(Command::STATUS_ONESHOT_REALTIME);
    commands.push_back(popNextCommand());
    // try remaining uris
    _requestGroup->createNextCommandWithAdj(commands, e, -1);
  } else {
    if(_currentRequest.isNull()) {
      _requestGroup->createNextCommandWithAdj(commands, e, 0);
    } else {
      Command* command =
	InitiateConnectionCommandFactory::createInitiateConnectionCommand
	(e->newCUID(), _currentRequest, _requestGroup, e);

      commands.push_back(command);

      _requestGroup->createNextCommandWithAdj(commands, e, -1);
    }
  }
}

} // namespace aria2
